@@ -90,7 +90,7 @@ def main_standalone( argc, argv ):
         piso, nCorr, nNonOrthCorr, momentumPredictor, transonic, nOuterCorr = readPISOControls( mesh ) 
         
         from Foam.finiteVolume.cfdTools.incompressible import CourantNo
-        CoNum, meanCoNum, velMag = CourantNo( mesh, phi, runTime )
+        CoNum, meanCoNum = CourantNo( mesh, phi, runTime )
         
         fluid.correct()
         from Foam import fvm, fvc
@@ -144,8 +144,8 @@ def main_standalone( argc, argv ):
 
 
 #--------------------------------------------------------------------------------------
-from Foam import FOAM_BRANCH_VERSION
-if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
+from Foam import FOAM_REF_VERSION
+if FOAM_REF_VERSION( ">=", "010600" ):
    if __name__ == "__main__" :
      import sys, os
      argv = sys.argv
@@ -154,5 +154,6 @@ if FOAM_BRANCH_VERSION( "dev", ">=", "010600" ):
    pass
 else:
    from Foam.OpenFOAM import ext_Info
-   ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-1.6-ext or higher\n"
-   pass   
+   ext_Info() << "\n\n To use this solver it is necessary to SWIG OpenFOAM-1.6 or higher\n"
+   pass
+
